%global reldate 20110606
%global rcver -beta3

%define base_name poi

Name:           apache-poi
Version:        3.8
Release:        %mkrel 1
Summary:        The Java API for Microsoft Documents
Group:          Development/Java
License:        ASL 2.0
URL:            http://poi.apache.org/
#Source0:        http://www.apache.org/dist/poi/release/src/poi-src-%{version}-%{reldate}.tar.gz
Source0:        http://www.apache.org/dist/poi/dev/src/poi-src-%{version}%{?rcver}-%{reldate}.tar.gz
# from http://www.ecma-international.org/publications/files/ECMA-ST/Office Open XML 1st edition Part 4 (PDF).zip
Source1:        Office-Open-XML-1st-edition-Part-4-PDF.zip
Source2:        http://repo2.maven.org/maven2/org/apache/poi/poi/3.8-beta3/poi-3.8-beta3.pom
Source3:        http://repo2.maven.org/maven2/org/apache/poi/poi-examples/3.8-beta3/poi-examples-3.8-beta3.pom
Source4:        http://repo2.maven.org/maven2/org/apache/poi/poi-ooxml/3.8-beta3/poi-ooxml-3.8-beta3.pom
Source5:        http://repo2.maven.org/maven2/org/apache/poi/poi-ooxml-schemas/3.8-beta3/poi-ooxml-schemas-3.8-beta3.pom
Source6:        http://repo2.maven.org/maven2/org/apache/poi/poi-scratchpad/3.8-beta3/poi-scratchpad-3.8-beta3.pom
#Force compile of xsds if disconnected
Patch1:         apache-poi-3.7-compile-xsds.patch

BuildArch:      noarch
#ExcludeArch:    ppc64

BuildRequires:  jpackage-utils
BuildRequires:  java-devel
BuildRequires:  ant-junit
BuildRequires:  dom4j
BuildRequires:  apache-commons-logging
BuildRequires:  junit
#Fonts for testing
BuildRequires:  fontconfig 
BuildRequires:  fonts-ttf-liberation
BuildRequires:  log4j
BuildRequires:  xmlbeans

Requires:       jpackage-utils
Requires:       java
Requires:       dom4j
Requires:       apache-commons-logging
Requires:       log4j
Requires:       xmlbeans
Provides:       jakarta-poi = %{version}

%description
The Apache POI Project's mission is to create and maintain Java APIs for
manipulating various file formats based upon the Office Open XML standards
(OOXML) and Microsoft's OLE 2 Compound Document format (OLE2). In short, you
can read and write MS Excel files using Java. In addition, you can read and
write MS Word and MS PowerPoint files using Java. Apache POI is your Java
Excel solution (for Excel 97-2008). We have a complete API for porting other
OOXML and OLE2 formats and welcome others to participate.

OLE2 files include most Microsoft Office files such as XLS, DOC, and PPT as
well as MFC serialization API based file formats. The project provides APIs
for the OLE2 Filesystem (POIFS) and OLE2 Document Properties (HPSF).

Office OpenXML Format is the new standards based XML file format found in
Microsoft Office 2007 and 2008. This includes XLSX, DOCX and PPTX. The
project provides a low level API to support the Open Packaging Conventions
using openxml4j.

For each MS Office application there exists a component module that attempts
to provide a common high level Java API to both OLE2 and OOXML document
formats. This is most developed for Excel workbooks (SS=HSSF+XSSF). Work is
progressing for Word documents (HWPF+XWPF) and PowerPoint presentations
(HSLF+XSLF).

The project has recently added support for Outlook (HSMF). Microsoft opened
the specifications to this format in October 2007. We would welcome
contributions.

There are also projects for Visio (HDGF) and Publisher (HPBF). 


%package javadoc
Summary:        Javadocs for %{name}
Group:          Development/Java
Requires:       jpackage-utils

%description javadoc
This package contains the API documentation for %{name}.


%package manual
Summary:        Manual for %{name}
Group:          Development/Java
Requires:       jpackage-utils
Requires:       %{name}-javadoc = %{version}-%{release}

%description manual
The manual for %{name}.


%prep
%setup -q -n poi-%{version}%{?rcver}
%patch1 -p1 -b .compile-xsds
find -name '*.class' -exec rm -f '{}' \;
find -name '*.jar' -exec rm -f '{}' \;
mkdir lib ooxml-lib
build-jar-repository -s -p lib ant commons-codec commons-logging junit log4j
build-jar-repository -s -p ooxml-lib dom4j xmlbeans/xbean
#Unpack the XMLSchema
pushd ooxml-lib
unzip "%{SOURCE1}" OfficeOpenXML-XMLSchema.zip
popd


%build
cat > build.properties <<'EOF'
main.ant.jar=lib/ant.jar
main.commons-codec.jar=lib/commons-codec.jar
main.commons-logging.jar=lib/commons-logging.jar
main.log4j.jar=lib/log4j.jar
main.junit.jar=lib/junit.jar
ooxml.dom4j.jar=ooxml-lib/dom4j.jar
ooxml.xmlbeans.jar=ooxml-lib/xmlbeans_xbean.jar
disconnected=1
DSTAMP=%{reldate}
EOF
export ANT_OPTS="-Xmx768m"
ant -propertyfile build.properties compile-ooxml-xsds jar


%install
rm -rf %{buildroot}
mkdir -p %{buildroot}%{_javadir}/poi
for jar in poi poi-examples poi-ooxml poi-ooxml-schemas poi-scratchpad
do
  cp -p build/dist/${jar}-%{version}%{?rcver}-%{reldate}.jar   \
        %{buildroot}%{_javadir}/poi/apache-${jar}.jar
  ln -s apache-${jar}.jar %{buildroot}%{_javadir}/poi/${jar}.jar
done

#pom
mkdir -p  %{buildroot}%{_mavenpomdir}
cp -p %SOURCE2 %{buildroot}%{_mavenpomdir}/JPP.%{base_name}-%{base_name}.pom
%add_maven_depmap JPP.%{base_name}-%{base_name}.pom %{base_name}/%{base_name}.jar
cp -p %SOURCE3 %{buildroot}%{_mavenpomdir}/JPP.%{base_name}-%{base_name}-examples.pom
%add_maven_depmap JPP.%{base_name}-%{base_name}-examples.pom %{base_name}/%{base_name}-examples.jar
cp -p %SOURCE4 %{buildroot}%{_mavenpomdir}/JPP.%{base_name}-%{base_name}-ooxml.pom
%add_maven_depmap JPP.%{base_name}-%{base_name}-ooxml.pom %{base_name}/%{base_name}-ooxml.jar
cp -p %SOURCE5 %{buildroot}%{_mavenpomdir}/JPP.%{base_name}-%{base_name}-ooxml-schemas.pom
%add_maven_depmap JPP.%{base_name}-%{base_name}-ooxml-schemas.pom %{base_name}/%{base_name}-ooxml-schemas.jar
cp -p %SOURCE6 %{buildroot}%{_mavenpomdir}/JPP.%{base_name}-%{base_name}-scratchpad.pom
%add_maven_depmap JPP.%{base_name}-%{base_name}-scratchpad.pom %{base_name}/%{base_name}-scratchpad.jar

#javadoc
mkdir -p %{buildroot}%{_javadocdir}
cp -pr docs/apidocs %{buildroot}%{_javadocdir}/%{name}
#Don't copy for manual
rm -rf docs/apidocs 

#manual - Link to javadoc location
ln -s ../../javadoc/%{name} docs/apidocs

%check
ant -propertyfile build.properties test

%post
%update_maven_depmap

%postun
%update_maven_depmap

%files
%doc KEYS LICENSE NOTICE
%{_javadir}/%{base_name}/%{name}-examples.jar
%{_javadir}/%{base_name}/%{name}-ooxml-schemas.jar
%{_javadir}/%{base_name}/%{name}-ooxml.jar
%{_javadir}/%{base_name}/%{name}-scratchpad.jar
%{_javadir}/%{base_name}/%{name}.jar
%{_javadir}/%{base_name}/%{base_name}-examples.jar
%{_javadir}/%{base_name}/%{base_name}-ooxml-schemas.jar
%{_javadir}/%{base_name}/%{base_name}-ooxml.jar
%{_javadir}/%{base_name}/%{base_name}-scratchpad.jar
%{_javadir}/%{base_name}/%{base_name}.jar
%{_mavendepmapfragdir}/*
%{_mavenpomdir}/*

%files javadoc
%doc LICENSE
%{_javadocdir}/%{name}

%files manual
%doc LICENSE docs/*



%changelog
* Sun Aug 14 2011 dmorgan <dmorgan> 3.8-1.mga2
+ Revision: 133026
- Clean spec file

  + gil <gil>
    - imported package apache-poi

